# Security Policy

## Reporting a Vulnerability

We are a small, academic project without a formal security process.

If you find a security vulnerability, please contact <mkhorton@lbl.gov> and CC <feedback@materialsproject.org>.

PGP keys can be made available on request.
